/*
 *    Digital Invisible Ink Toolkit
 *    Copyright (C) 2005  K. Hempstalk	
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package invisibleinktoolkit.gui;

import javax.swing.JWindow;
import java.awt.Label;
import java.awt.Frame;


/**
 * A non-blocking window to state "Working, please wait".
 *
 * @author Kathryn Hempstalk.
 */
public class WorkingPanel {
	
	//CONSTRUCTORS
	
	/**
	 * Sets up a working panel that displays "Working, please wait".
	 *
	 * @param parent The parent frame this will replace on screen.
	 */
	public WorkingPanel(Frame parent){
		mDialog = new JWindow(parent);
		Label label = new Label("    WORKING, PLEASE WAIT...  ");
		label.setSize(180,30);
		mDialog.getContentPane().add(label);
		mDialog.pack();
		mDialog.repaint();
		mDialog.setLocationRelativeTo(parent);
	}
	
	//FUNCTIONS
	
	/**
	 * Shows this dialog centered on the parent on screen.
	 */
	public void show(){
		mDialog.setVisible(true);
	}
	
	/**
	 * Hides this dialog.
	 */
	public void hide(){
		mDialog.setVisible(false);
	}
	
	
	//VARIABLES
	
	/**
	 * The dialog being hidden/shown.
	 */
	private JWindow mDialog;
}
//end of class.
